#(HELLO_BEFORE_AMBUSH_1) 2593,5649,4987,5408,4376,2614,3064
#(HELLO_BEFORE_AMBUSH_2) 2314
#(HELLO_BEFORE_AMBUSH_3) 1652
#(HELLO_BEFORE_AMBUSH_4) 
#(we_are_vice_squad) 
#(OK_VICE) 3365,3244,5839
#(we_are_the_one_for_you_baby) 
#(MAYBE_CAPTAIN) 7190,4136
#(we_are_vindicator0) 
#(we_are_vindicator1) 
#(we_are_vindicator2) 
#(WELCOME_VINDICATOR0) 
#(WELCOME_VINDICATOR1) 
#(WELCOME_VINDICATOR2) 
#(we_are_impressed) 
#(SO_AM_I_CAPTAIN) 4075
#(HOW_CAN_YOU_BE_HERE) 2914,3696,3094,2604
#(we_here_to_help) 
#(NO_NEED_HELP) 5919,2624,5728,6419,7731
#(we_need_help) 
#(CANT_GIVE_HELP) 6860,5257,3525,4957,7371
#(i_need_you) 
#(OK_NEED) 3866,6029,4917,6279,3465
#(i_need_touch_o_vision) 
#(TOUCH_O_VISION) 2944,5758,5088,6529,3565
#(know_about_deep_children) 
#(WHAT_ABOUT_DEEP_CHILDREN) 5588,7220,4397,4586
#(mycons_involved) 
#(WHAT_PROOF) 2784,6880,3625,7611
#(have_no_proof) 
#(NEED_PROOF) 7060,6560,5578,6629,3926,6609,6860,6390
#(have_proof) 
#(SEE_PROOF) 
#(look_at_egg_sacks) 
#(HORRIBLE_TRUTH) 8362,4116,5829,4907,4156,4306,8392,4707
#(what_doing_here) 
#(OUR_NEW_WORLD) 3806,3865,4847,4987,4867,5228,5978,5889,5137,5158,3895,5699,7440,3075,5207,6149,6710,3485,4466,6509,5238,5538
#(what_about_war) 
#(ABOUT_WAR) 5598,3415,7430,6790,4387,5477,6109,6419,6890,6890,2584,5217,6290,4085,5659,5838,6329
#(help_us) 
#(WONT_HELP) 3896,3034,4927
#(what_about_history) 
#(BEFORE_WAR) 7594,3257,4661,3639,5469,6869,6398,5458,9497,4879,5800,6748,6448,3948
#(what_about_homeworld) 
#(ABOUT_HOMEWORLD) 3785,6800,7341,5247,6309,4086
#(what_happened) 
#(DONT_KNOW_HOW) 3395,3174,6159,5348,7030,7199,5619,2193,2885,5918,5768,5308,2744,6810,7240,3645,4106,5238
#(what_about_outfit) 
#(HOPE_YOU_LIKE_IT) 5739
#(where_mates) 
#(MATES_KILLED) 4997,5759,7731,8582,2544,7410,5598,7762,5457,9274,7461,2623,6139
#(get_lonely) 
#(MAKE_OUT_ALL_RIGHT) 3805
#(bye) 
#(GOODBYE) 
#(MUST_ACT) 2594,5368,4787,5287,4747
#(whats_next_step) 
#(OPEN_VAULT) 2594,5368,4787,5287,4747
#(where_is_it) 
#(DONT_KNOW_WHERE) 1993,3215,6379,5438,5348,6559,7491
#(been_there) 
#(GREAT) 
#(GIVE_SHUTTLE) 4546,3846,5157,2063,6059
#(im_on_my_way) 
#(doing_this_for_you) 
#(if_i_die) 
#(GOOD_LUCK) 3866
#(OK_FOUND_VAULT) 5809,4997,4146,5949,6759,3095,8151,2574,5989,8202,5578,3133,4417,3676
#(what_now) 
#(HERES_THE_PLAN) 5118,4166
#(whats_my_reward) 
#(HERES_REWARD) 3556,2523
#(bye_after_vault) 
#(GOODBYE_AFTER_VAULT) 
#(HELLO_AFTER_AMBUSH_1) 5098,2353,4366,3105,4436,3475,3395,5899,5698,5798,5628,5678,6239,4687,6910
#(HELLO_AFTER_AMBUSH_2) 4356,4757,7982,5778
#(HELLO_AFTER_AMBUSH_3) 6219,6379,4096,5077,4557,2103,4947
#(HELLO_AFTER_AMBUSH_4) 3936
#(what_now_after_ambush) 
#(DO_THIS_AFTER_AMBUSH) 5098,4676,3315,4196,5518,3215,5097
#(what_about_you) 
#(ABOUT_ME) 3495,3615,4026
#(whats_up_after_ambush) 
#(GENERAL_INFO_AFTER_AMBUSH_1) 5438,4086,4246
#(GENERAL_INFO_AFTER_AMBUSH_2) 4206,2284
#(GENERAL_INFO_AFTER_AMBUSH_3) 
#(GENERAL_INFO_AFTER_AMBUSH_4) 
#(bye_after_ambush) 
#(GOODBYE_AFTER_AMBUSH) 
#(FOUND_VAULT_YET_1) 
#(FOUND_VAULT_YET_2) 
#(vault_hint) 
#(OK_HINT) 
#(found_vault) 
#(bye_before_vault) 
#(GOODBYE_BEFORE_VAULT) 
#(what_do_i_get_for_this) 
#(GRATITUDE) 
#(not_sure) 
#(PLEASE) 
#(READY_FOR_AMBUSH) 
#(repeat_plan) 
#(OK_REPEAT_PLAN) 3365,5668,5097,3815
#(bye_before_ambush) 
#(GOODBYE_BEFORE_AMBUSH) 
#(what_about_us) 
#(ABOUT_US) 3315
#(MORE_COMFORTABLE) 2900,2200
#(in_the_spirit) 
#(OK_SPIRIT) 3635,3200,3900,2400,2500
#(what_in_mind) 
#(SOMETHING_LIKE_THIS) 5658,4000,8000,6000,6000
#(hands_off) 
#(OK_WONT_USE_HANDS) 6009,2293,6000,2700,3000
#(why_lights_off) 
#(LIGHTS_OFF_BECAUSE) 5500,2000,2700
#(evil_monster) 
#(NOT_EVIL_MONSTER) 5118,5899,3570
#(disease) 
#(JUST_RELAX) 
#(what_happens_if_i_touch_this) 
#(THIS_HAPPENS) 1835,1839,1169,3621
#(are_you_sure_this_is_ok) 
#(YES_SURE) 2774,2674
#(boy_they_never_taught) 
#(THEN_LET_ME_TEACH) 2533
#(not_much_more_to_say) 
#(THEN_STOP_TALKING) 3935
#(LATER) 1993,751,691
#(SEX_GOODBYE) 3925,1843,3876,6299
#(OUT_TAKES) 5500,5500,5000,5000,4000,3000,5500
